@@ -1194,10 +1194,11 @@ relational knowledge is contained in the default context GLOBAL.")
 
 (defun numer (x)
   (let (($numer t) ; currently, no effect on $float, but proposed to
+        ($ratprint nil)
         result)
-      ;; Catch a Lisp error, if a floating point overflow occurs.
-      (setq result (let ((errset nil)) (errset ($float x))))
-      (if result (car result) nil)))
+    ;; Catch a Lisp error, if a floating point overflow occurs.
+    (setq result (let ((errset nil)) (errset ($float x))))
+    (if result (car result) nil)))
 
 (defun constp (x)
   (cond ((floatp x) 'float)
@@ -1251,14 +1252,19 @@ relational knowledge is contained in the default context GLOBAL.")
 
 (defun sign-any (x)
   (cond ((and *complexsign*
-	      (or (and (atom x) (decl-complexp x))
-		  (and (not (atom x)) (decl-complexp (caar x)))))
-	 ;; In Complex Mode look for symbols declared to be complex.
-	 (when *debug-compar*
-	   (format t "~&SIGN-ANY with ~A~&   Symbol declared to be complex found.~%" x))
-	 (if (and (atom x) ($featurep x '$imaginary))
-	     (setq sign '$imaginary)
-	     (setq sign '$complex)))
+              (symbolp x)
+              (decl-complexp x))
+         ;; In Complex Mode look for symbols declared to be complex.
+         (if ($featurep x '$imaginary)
+             (setq sign '$imaginary)
+             (setq sign '$complex)))
+        ((and *complexsign*
+              (not (atom x))
+              (decl-complexp (caar x)))
+         ;; A function f(x), where f is declared to be imaginary or complex.
+         (if ($featurep (caar x) '$imaginary)
+             (setq sign '$imaginary)
+             (setq sign '$complex)))
 	(t
 	 (dcompare x 0)
 	 (if (and $assume_pos
@@ -1596,25 +1602,19 @@ relational knowledge is contained in the default context GLOBAL.")
 ;;; Determine the sign of log(expr). This function changes the special variable sign.
 
 (defun sign-log (x)
-  (setq x (cadr x)) ;; looking at sign of log(x)
-  (cond ((eq t (meqp x 1)) (setf sign '$zero)) ;; log(1) = 0.
-	;; for x on the unit circle and x # 1, log(x) is pure imaginary
-	((and  *complexsign* (eq t (meqp 1 (take '(mabs) x))) (eq t (mnqp x 1)))
-	 (setf sign '$imaginary))
-	;; log(x) is positive for x > 1
-	((eq t (mgrp x 1)) (setf sign '$pos))
-	((eq t (mgqp x 1)) (setf sign '$pz))
-	;; log(x) is negative for 0 < x < 1.
-	((and (eq t (mgrp x 0)) (eq t (mgrp 1 x))) (setf sign '$neg))
-
-	;; log(x) is real for x > 0
-	((eq t (mgrp x 0)) (setf sign '$pnz))
-
-	;; Nothing is known.  Return $complex if allowed, 
-	;;  otherwise pnz
-	(*complexsign* (setf sign '$complex)) 
-	(t (setf sign '$pnz)))
-  sign)
+  (setq x (cadr x))
+  (setq sign
+	(cond ((eq t (mgrp x 0))
+	       (cond ((eq t (mgrp 1 x)) '$neg)
+		     ((eq t (meqp x 1)) '$zero);; log(1) = 0.
+		     ((eq t (mgqp 1 x)) '$nz)
+		     ((eq t (mgrp x 1)) '$pos)
+		     ((eq t (mgqp x 1)) '$pz)
+		     ((eq t (mnqp x 1)) '$pn)
+		     (t '$pnz)))
+	      ((and  *complexsign* (eql 1 (cabs x))) '$imaginary)
+	      (*complexsign* '$complex)
+	      (t '$pnz))))
 
 (defun sign-mabs (x)
   (sign (cadr x))
